@@ -1,6 +1,9 @@
 from __future__ import annotations
 
-import uritemplate  # pylint: disable=E0401
+import copy
+from functools import partial
+
+import uritemplate
 from django.utils.encoding import smart_str
 from rest_framework.fields import Field
 from rest_framework.permissions import AllowAny
@@ -28,6 +31,7 @@ from .typing import (
     Sequence,
     SerializerType,
     Type,
+    TypeVar,
     Union,
 )
 from .utils import is_serializer_class
@@ -36,9 +40,12 @@ from .utils import is_serializer_class
 if TYPE_CHECKING:
     from .views import BasePipelineView
 
+    T = TypeVar("T", bound=Type[BasePipelineView])
+
 
 __all__ = [
     "convert_to_schema",
+    "deprecate",
     "PipelineEndpointEnumerator",
     "PipelineSchema",
     "PipelineSchemaGenerator",
@@ -47,6 +54,40 @@ __all__ = [
 ]
 
 
+def deprecate(__view: Optional[T] = None, *, methods: Optional[List[HTTPMethod]] = None) -> T:
+    """Deprecate a view in the OpenAPI schema while retaining the original.
+
+    :param methods: HTTP methods to deprecate. Deprecate all if not given.
+    """
+
+    def view(_view: T, _methods: Optional[List[HTTPMethod]] = None):
+        # Mock the "get_serializer_class" method to change the calculated "operation_id"
+        def new_get_serializer_class(old_method):
+            def inner(self, output: bool = False):
+                serializer = old_method.__get__(self, new_view)(output)  # pylint: disable=unnecessary-dunder-call
+                new_serializer = type(f"Deprecated{serializer.__name__}", (serializer,), {})
+                new_serializer.__doc__ = serializer.__doc__
+                return new_serializer
+
+            return inner
+
+        new_view: T = type(f"Deprecated{_view.__name__}", (_view,), {})  # type: ignore
+        new_view.__doc__ = _view.__doc__
+        new_view.get_serializer_class = new_get_serializer_class(new_view.get_serializer_class)
+
+        if _methods is None:
+            _methods = list(new_view.pipelines)
+
+        new_view.schema = copy.deepcopy(new_view.schema)
+        new_view.schema.deprecated = _methods
+        return new_view
+
+    if callable(__view):
+        return view(__view, methods)  # type: ignore
+
+    return partial(view, _methods=methods)  # type: ignore
+
+
 def convert_to_schema(schema: Union[List[Any], Dict[str, Any], Any]) -> Dict[str, Any]:
     """Recursively convert a json-like object to OpenAPI example response."""
 
@@ -110,12 +151,12 @@ class PipelineSchemaMixin:
 
         return operation
 
-    def get_description(self, path: str, method: HTTPMethod) -> str:  # pylint: disable=W0613
+    def get_description(self, path: str, method: HTTPMethod) -> str:
         serializer_class = self.view.get_serializer_class()
         description = serializer_class.__doc__ or (self.view.__class__.__doc__ or "")
         return self._get_description_section(self.view, method, formatting.dedent(smart_str(description)))
 
-    def get_components(self, path: str, method: HTTPMethod) -> Dict[str, Any]:  # pylint: disable=W0613
+    def get_components(self, path: str, method: HTTPMethod) -> Dict[str, Any]:
         request_serializer_class = self.view.get_serializer_class()
         response_serializer_class = self.view.get_serializer_class(output=True)
 
@@ -171,7 +212,7 @@ class PipelineSchemaMixin:
 
         return {"content": {content_type: item_schema for content_type in request_media_types}}
 
-    def get_responses(self, path: str, method: HTTPMethod) -> Dict[str, Any]:  # pylint: disable=W0613
+    def get_responses(self, path: str, method: HTTPMethod) -> Dict[str, Any]:
         data = {}
 
         responses = self.responses.get(method, {})
@@ -222,7 +263,7 @@ class PipelineSchemaMixin:
 
         return data
 
-    def get_tags(self, path: str, method: HTTPMethod) -> List[str]:  # pylint: disable=W0613
+    def get_tags(self, path: str, method: HTTPMethod) -> List[str]:
         if self._tags:
             return self._tags
 
@@ -288,7 +329,7 @@ class PipelineSchemaMixin:
             if serializer.fields:
                 response_schema = {"schema": self.map_serializer(serializer)}
             else:
-                response_schema = {"schema": convert_to_schema(serializer._example)}  # pylint: disable=W0212
+                response_schema = {"schema": convert_to_schema(serializer._example)}  # pylint: disable=protected-access
 
         elif isinstance(serializer, EmptySerializer):
             response_schema = self._get_no_result_schema()
@@ -328,10 +369,10 @@ class PipelineSchemaMixin:
             "properties": {"detail": {"type": "string", "default": error_message}},
         }
 
-    def get_request_serializer(self, path: str, method: HTTPMethod) -> BaseSerializer:  # pylint: disable=W0613
+    def get_request_serializer(self, path: str, method: HTTPMethod) -> BaseSerializer:
         return self.view.get_serializer()
 
-    def get_response_serializer(self, path: str, method: HTTPMethod) -> BaseSerializer:  # pylint: disable=W0613
+    def get_response_serializer(self, path: str, method: HTTPMethod) -> BaseSerializer:
         return self.view.get_serializer(output=True)
 
 
